<?php
/**
 * Copyright 2023 © Pinpoint Designs. All rights reserved.
 */
namespace Pinpoint\PdfUpload\Controller\Adminhtml\Wysiwyg\Images;

use Magento\Backend\App\Action;
use Magento\Cms\Helper\Wysiwyg\Images;
use Magento\Framework\Controller\Result\Raw;
use Magento\Framework\Controller\Result\RawFactory;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Registry;
use Magento\Framework\View\Asset\Repository;

/**
 * Class Thumbnail
 * @package Pinpoint\PdfUpload\Controller\Adminhtml\Wysiwyg\Images
 */
class Thumbnail extends \Magento\Cms\Controller\Adminhtml\Wysiwyg\Images\Thumbnail
{
    /**
     * @var string
     */
    const PDF_ICON = 'Pinpoint_PdfUpload::images/pdf-icon.png';

    /**
     * @var Repository
     */
    protected $assetRepository;

    /**
     * @var Images
     */
    protected $images;

    /**
     * Thumbnail constructor.
     * @param Action\Context $context
     * @param Registry       $coreRegistry
     * @param RawFactory     $resultRawFactory
     * @param Repository     $assetRepository
     * @param Images         $images
     */
    public function __construct(
        Action\Context $context,
        Registry $coreRegistry,
        RawFactory $resultRawFactory,
        Repository $assetRepository,
        Images $images
    ) {
        $this->assetRepository = $assetRepository;
        $this->images = $images;
        parent::__construct($context, $coreRegistry, $resultRawFactory);
    }

    /**
     * @return Raw
     * @throws LocalizedException
     */
    public function execute(): Raw
    {
        $file = $this->getRequest()->getParam('file');
        $file = $this->images->idDecode($file);
        $params = [
            'area' => 'adminhtml'
        ];

        switch (pathinfo($file, PATHINFO_EXTENSION)) {
            case "pdf":
                $icon = self::PDF_ICON;
                break;
            default:
                return parent::execute();
        }
        $asset = $this->assetRepository->createAsset($icon, $params);
        $resultRaw = $this->resultRawFactory->create();
        $resultRaw->setHeader('Content-Type', 'image/' . $asset->getContentType());
        $resultRaw->setContents($asset->getContent());
        return $resultRaw;
    }
}
