<?php
/**
 * Copyright 2023 © Pinpoint Designs. All rights reserved.
 */
namespace Pinpoint\PdfUpload\Model\Cms\Wysiwyg\Images;

use Exception;
use Magento\Framework\Exception\FileSystemException;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Exception\ValidatorException;

class Storage extends \Magento\Cms\Model\Wysiwyg\Images\Storage
{
    /**
     * @var string
     */
    const PDF_EXT = 'pdf';

    /**
     * @throws FileSystemException
     * @throws ValidatorException
     * @throws LocalizedException
     * @throws Exception
     */
    public function uploadFile($targetPath, $type = null)
    {

        $uploader = $this->_uploaderFactory->create(['fileId' => 'image']);
        $allowed = $this->getAllowedExtensions($type);
        if ($allowed) {
            $allowed = array_merge($allowed, [self::PDF_EXT]);
            $uploader->setAllowedExtensions($allowed);
        }
        $uploader->setAllowRenameFiles(true);
        $uploader->setFilesDispersion(false);
        $result = $uploader->save($targetPath);

        if (!$result) {
            throw new LocalizedException(__('We can\'t upload the file right now.'));
        }

        if (!in_array($uploader->getFileExtension(), [self::PDF_EXT])) {

            $this->resizeFile($targetPath . '/' . $uploader->getUploadedFileName(), true);
        }

        $result['cookie'] = [
            'name' => $this->getSession()->getName(),
            'value' => $this->getSession()->getSessionId(),
            'lifetime' => $this->getSession()->getCookieLifetime(),
            'path' => $this->getSession()->getCookiePath(),
            'domain' => $this->getSession()->getCookieDomain(),
        ];

        return $result;
    }
}
